@@ -55,6 +55,11 @@ class ModifyDBInstanceConnectionStringRequest(RpcRequest):
 
 	def set_OwnerAccount(self, OwnerAccount):  # String
 		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_NewPort(self): # Integer
+		return self.get_query_params().get('NewPort')
+
+	def set_NewPort(self, NewPort):  # Integer
+		self.add_query_param('NewPort', NewPort)
 	def get_NewConnectionString(self): # String
 		return self.get_query_params().get('NewConnectionString')
 
